==> libreoffice-4.0.5.2.tar.xz: libreoffice-4.0.5.2/nlpsolver/ThirdParty/EvolutionarySolver/src/net/adaptivebox/global/BasicTag.java <==
/**
 * Description: defines some static constant values.
 *
 * @ Author        Create/Modi     Note
 * Xiaofeng Xie    Sep 22, 2000    xiaofengxie@tsinghua.org.cn
 *
 * @version 1.0
 * @Since MAOS1.0
 */

package net.adaptivebox.global;


public class BasicTag {
  public static final String COMMAND_TAG = "%";
  public static final String TAB_TAG = "\t";
  public static final String LEFT_SMALL_BRACKET_TAG = "(";
  public static final String RIGHT_SMALL_BRACKET_TAG = ")";
  public static final String LEFT_LARGE_BRACKET_TAG = "{";
  public static final String RIGHT_LARGE_BRACKET_TAG = "}";
  public static final String LEFT_BRACKET_TAG = "[";
  public static final String RIGHT_BRACKET_TAG = "]";
  public static final String EQUAL_TAG = "=";
  public static final String SPACE_TAG = " ";
  public static final String SEMICOLON_TAG = ";";
  public static final String COLON_TAG = ":";
  public static final String COMMA_TAG = ",";
  public static final String DOT_TAG = ".";
  public static final String NULL_SEPERATE_TAG = " \t";
  public static final String SEPERATE_TAG = "|";
  public static final String UNDERLINE_TAG = "_";
  public static final String INC_TAG = "+";
  public static final String DEC_TAG = "-";
  public static final String ZERO_TAG = "0";
  public static final String EXP_TAG = "E";
  public static final String S_EXP_TAG = "e";
  public static final String FILE_SEP_TAG = System.getProperty("file.separator");
  public static final String RETURN_TAG = System.getProperty("line.separator");
}

==> libreoffice_4.2.3~rc3.orig.tar.xz: libreoffice-4.2.3~rc3/nlpsolver/ThirdParty/EvolutionarySolver/src/net/adaptivebox/global/BasicTag.java <==
/**
 * Description: defines some static constant values.
 *
 * @ Author        Create/Modi     Note
 * Xiaofeng Xie    Sep 22, 2000    xiaofengxie@tsinghua.org.cn
 *
 * @version 1.0
 * @Since MAOS1.0
 */

package net.adaptivebox.global;


public class BasicTag {
  public static final String COMMAND_TAG = "%";
  public static final String TAB_TAG = "\t";
  public static final String LEFT_SMALL_BRACKET_TAG = "(";
  public static final String RIGHT_SMALL_BRACKET_TAG = ")";
  public static final String LEFT_LARGE_BRACKET_TAG = "{";
  public static final String RIGHT_LARGE_BRACKET_TAG = "}";
  public static final String LEFT_BRACKET_TAG = "[";
  public static final String RIGHT_BRACKET_TAG = "]";
  public static final String EQUAL_TAG = "=";
  public static final String SPACE_TAG = " ";
  public static final String SEMICOLON_TAG = ";";
  public static final String COLON_TAG = ":";
  public static final String COMMA_TAG = ",";
  public static final String DOT_TAG = ".";
  public static final String NULL_SEPARATE_TAG = " \t";
  public static final String SEPARATE_TAG = "|";
  public static final String UNDERLINE_TAG = "_";
  public static final String INC_TAG = "+";
  public static final String DEC_TAG = "-";
  public static final String ZERO_TAG = "0";
  public static final String EXP_TAG = "E";
  public static final String S_EXP_TAG = "e";
  public static final String FILE_SEP_TAG = System.getProperty("file.separator");
  public static final String RETURN_TAG = System.getProperty("line.separator");
}
